@@ -242,7 +242,7 @@ settings_list_sessions_open_rc (void)
 
   if (!g_file_test (session_file, G_FILE_TEST_IS_REGULAR))
     {
-      g_warning ("xfsm_manager_load_session: Something wrong with %s, Does it exist? Permissions issue?", session_file);
+      g_debug ("xfsm_manager_load_session: Something wrong with %s, Does it exist? Permissions issue?", session_file);
       return FALSE;
     }
 
@@ -350,6 +350,23 @@ settings_list_sessions_treeview_init (GtkTreeView *treeview)
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 }
 
+static gint
+compare_session_atime (XfsmSessionInfo *session1,
+                       XfsmSessionInfo *session2)
+{
+  if (session1->atime < session2->atime)
+    return 1;
+  if (session1->atime > session2->atime)
+    return -1;
+  return 0;
+}
+
+static GList *
+sort_sessions_on_atime (GList *sessions)
+{
+  return g_list_sort (sessions, (GCompareFunc) compare_session_atime);
+}
+
 void
 settings_list_sessions_populate (GtkTreeModel *model,
                                  GList        *sessions)
@@ -360,6 +377,8 @@ settings_list_sessions_populate (GtkTreeModel *model,
   gchar           *title;
   GList           *lp;
 
+  sessions = sort_sessions_on_atime (sessions);
+
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
   for (lp = sessions; lp != NULL; lp = lp->next)
